@@ -1,6 +1,6 @@
-// ----------------------------------------------------------------------
+// ----------------------------------------------------------------------------
 //
-//  Copyright (C) 2011 Fons Adriaensen <fons@linuxaudio.org>
+//  Copyright (C) 2008-2024 Fons Adriaensen <fons@linuxaudio.org>
 //    
 //  This program is free software; you can redistribute it and/or modify
 //  it under the terms of the GNU General Public License as published by
@@ -13,10 +13,9 @@
 //  GNU General Public License for more details.
 //
 //  You should have received a copy of the GNU General Public License
-//  along with this program; if not, write to the Free Software
-//  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+//  along with this program.  If not, see <http://www.gnu.org/licenses/>.
 //
-// ----------------------------------------------------------------------
+// ----------------------------------------------------------------------------
 
 
 #include <stdio.h>
@@ -127,6 +126,7 @@ void Shuffler::prepare (float gain, float freq)
     }
     _fft_time [0] = 0;
     _fft_time [h] = 1;
+    _convproc.impdata_clear (0, 0);
     _convproc.impdata_update (0, 0, 1, _fft_time, 0, _iplen);
 
     _touch0++;
